Module: YARD
- Defined in:
- lib/dsl/bm_dsl.rb,
lib/dsl/monkeypatches.rb,
lib/yard-bench/handler.rb,
lib/yard-bench/version.rb
Overview
FIXME Probably, that class is to be made as Proxy. Then during the methods processing we’ll have an access to it to print the benchmarks out within method scope…
Defined Under Namespace
Modules: Bench, Handlers, MonkeyPatches